==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ArrayContext.h <==
// class gnu.java.beans.decoder.ArrayContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class d67e0160feebd70 gnu_java_beans_decoder_ArrayContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_ArrayContext_H_
#define _JC_gnu_java_beans_decoder_ArrayContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$sub_refs	_jc_gnu_java_beans_decoder_ArrayContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$refs	_jc_gnu_java_beans_decoder_ArrayContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$nonrefs	_jc_gnu_java_beans_decoder_ArrayContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$object	_jc_gnu_java_beans_decoder_ArrayContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vmethods	_jc_gnu_java_beans_decoder_ArrayContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vtable	_jc_gnu_java_beans_decoder_ArrayContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vtype	_jc_gnu_java_beans_decoder_ArrayContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$_init$f10897f332c0167b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *, jint);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *);
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint, struct _jc_java_lang_Object$object *);
extern jboolean _jc_gnu_java_beans_decoder_ArrayContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ArrayContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint);
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *);
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *);
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint, struct _jc_java_lang_Object$object *);
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ArrayContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_ArrayContext$vmethods	gnu_java_beans_decoder_ArrayContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ArrayContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ArrayContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayContext$sub_refs {
	struct _jc_java_lang_Object$object	*array;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayContext$refs {
    _jc_gnu_java_beans_decoder_ArrayContext$sub_refs	gnu_java_beans_decoder_ArrayContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs	gnu_java_beans_decoder_ArrayContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ArrayContext$object {
	_jc_gnu_java_beans_decoder_ArrayContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ArrayContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ArrayContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ArrayContext$vtype _jc_gnu_java_beans_decoder_ArrayContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ArrayContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ArrayContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ArrayContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ArrayContext.h <==
// class gnu.java.beans.decoder.ArrayContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class d67e0160feebd70 gnu_java_beans_decoder_ArrayContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_ArrayContext_H_
#define _JC_gnu_java_beans_decoder_ArrayContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$sub_refs	_jc_gnu_java_beans_decoder_ArrayContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$refs	_jc_gnu_java_beans_decoder_ArrayContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$nonrefs	_jc_gnu_java_beans_decoder_ArrayContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayContext$object	_jc_gnu_java_beans_decoder_ArrayContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vmethods	_jc_gnu_java_beans_decoder_ArrayContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vtable	_jc_gnu_java_beans_decoder_ArrayContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ArrayContext$vtype	_jc_gnu_java_beans_decoder_ArrayContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$_init$f10897f332c0167b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ArrayContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ArrayContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_ArrayContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_ArrayContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ArrayContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *) _JC_JCNI_ATTR;
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ArrayContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_ArrayContext$vmethods	gnu_java_beans_decoder_ArrayContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ArrayContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ArrayContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayContext$sub_refs {
	struct _jc_java_lang_Object$object	*array;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayContext$refs {
    _jc_gnu_java_beans_decoder_ArrayContext$sub_refs	gnu_java_beans_decoder_ArrayContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_ArrayContext$sub_nonrefs	gnu_java_beans_decoder_ArrayContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ArrayContext$object {
	_jc_gnu_java_beans_decoder_ArrayContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ArrayContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ArrayContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ArrayContext$vtype _jc_gnu_java_beans_decoder_ArrayContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ArrayContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ArrayContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ArrayContext_H_ */
